pub enum Error {
IoError(Error),
Utf8Error(Utf8Error),
FmtError(Error),
IncompleteFrame,
}Expand description
Errors that may occur while encoding or decoding server-sent event messages.
Variants
IoError(Error)
An I/O error occurred while reading or writing a stream.
Utf8Error(Utf8Error)
Incoming data is not valid utf-8.
FmtError(Error)
An error occurred while writing an event message.
IncompleteFrame
Tried to read an incomplete frame.